Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/dht_simpletest.py
    :caption: examples/dht_simpletest.py
    :linenos:


Time calibration advance test
------------------------------

Check what is the best time your sensor.

.. literalinclude:: ../examples/dht_time_calibration_advance.py
    :caption: examples/dht_time_calibration_advance.py
    :linenos:
